@@ -4,13 +4,13 @@ use 5.008000;
 use strict;
 use warnings;
 
-our $VERSION = '0.15_01';
+our $VERSION = '0.19_01';
 
 use File::Spec;
 use YAML::XS qw( LoadFile );
 use Cpanel::JSON::XS;
 use Hash::Merge;
-use Scalar::Util qw( refaddr );
+use Scalar::Util qw( refaddr readonly );
 use Carp qw( croak );
 
 my %FILE_EXTENSIONS_MAP = (
@@ -195,6 +195,8 @@ sub _load_json {
 sub _process_tree {
   my $self = shift;
 
+  return if readonly( $_[0] );
+
   $_[0] = $self->_process_node( $_[0] );
 
   if ( my $node_addr = refaddr( $_[0] ) ) {
@@ -287,6 +289,8 @@ sub _resolve_var {
 
     while (1) {
       my $token = shift @tokens;
+      $token =~ s/^\s+//;
+      $token =~ s/\s+$//;
 
       if ( ref($pointer) eq 'HASH' ) {
         last unless defined $pointer->{$token};
@@ -344,10 +348,10 @@ features
   use Config::Processor;
 
   my $config_processor = Config::Processor->new(
-    dirs => [ qw( /etc/myapp /home/username/etc/myapp ) ],
+    dirs => [qw( /etc/myapp /home/username/etc/myapp )]
   );
 
-  my $config = $config_processor->load( qw( dirs.yml db.json metrics/* ) );
+  my $config = $config_processor->load(qw( dirs.yml db.json metrics/* ));
 
   $config = $config_processor->load(
     qw( dirs.yml db.json redis.yml mongodb.json metrics/* ),
@@ -378,13 +382,14 @@ F<.yaml>, F<.jsn>, F<.json>.
 =head2 new( %params )
 
   my $config_processor = Config::Processor->new(
-    dirs => [ qw( /etc/myapp /home/username/etc/myapp ) ],
+    dirs       => [qw( /etc/myapp /home/username/etc/myapp )],
+    export_env => 1,
   );
 
-  $config_processor = Config::Processor->new();
+  $config_processor = Config::Processor->new;
 
   $config_processor = Config::Processor->new(
-    dirs                  => [ qw( /etc/myapp /home/username/etc/myapp ) ],
+    dirs                  => [qw( /etc/myapp /home/username/etc/myapp )],
     interpolate_variables => 0,
     process_directives    => 0,
   );
@@ -406,9 +411,12 @@ Enabled by default.
 Enables or disables directive processing in configurations files.
 Enabled by default.
 
-=item export_env
+=item export_env => $boolean
 
 Enables or disables environment variables exporting to configuration tree.
+If enabled, environment variables can be accessed by the key C<ENV> from the
+configuration tree and can be interpolated into other configuration parameters.
+
 Disabled by default.
 
 =back
